<?php

defined('C5_EXECUTE') or die('Access Denied.');

/**
 * @var Concrete\Core\Block\View\BlockView $view
 * @var Xanweb\LiteSlider\Form\Service\Form $form
 * @var Xanweb\LsHtmlHelper\Service\Form\IosTogglerWidget $togglerWidget
 * @var int $maxWidth
 * @var array $thumbnailOptions
 * @var bool $useCustomThumbnailsSetting
 * @var int $largeDesktopThumbnail
 * @var int $desktopThumbnail
 * @var int $tabletThumbnail
 * @var int $phoneThumbnail
 * @var string $uniqID
 * @var Concrete\Core\Form\Service\Widget\Color $formColor
 * @var array $colorPickerOptions
 * @var string $defaultTitleColor
 * @var string $defaultOverlayColor
 * @var string $defaultBoxColor
 * @var string $navigationColor
 */
?>

<fieldset>
    <legend><?php echo t('Settings') ?></legend>

    <div class="form-group">
        <?php echo $form->label($view->field('maxWidth'), t('Maximum Slide Width (0 means no limit)')) ?>
        <div class="input-group" style="width: 150px">
            <?php echo $form->number($view->field('maxWidth'), $maxWidth , ['min' => 0, 'max' => 9999]) ?>
            <span class="input-group-addon"><?php echo t('px') ?></span>
        </div>
    </div>

    <h4><?php echo t('Colors') ?></h4>
    <div class="row">
        <div class="col-xs-6">
            <div class="form-group">
                <?php echo $form->label('defaultTitleColor', t('Default Title Color')); ?>
                <?php echo $formColor->output('defaultTitleColor', $defaultTitleColor, $colorPickerOptions) ?>
            </div>
        </div>
        <div class="col-xs-6">
            <div class="form-group">
                <?php echo $form->label('defaultOverlayColor', t('Default Overlay Color')); ?>
                <?php echo $formColor->output('defaultOverlayColor', $defaultOverlayColor, $colorPickerOptions) ?>
            </div>
        </div>
        <div class="col-xs-6">
            <div class="form-group">
                <?php echo $form->label('defaultBoxColor', t('Default Box Color')); ?>
                <?php echo $formColor->output('defaultBoxColor', $defaultBoxColor, $colorPickerOptions) ?>
            </div>
        </div>
        <div class="col-xs-6">
            <div class="form-group">
                <?php echo $form->label('navigationColor', t('Navigation Color')); ?>
                <?php echo $formColor->output('navigationColor', $navigationColor, $colorPickerOptions) ?>
            </div>
        </div>
    </div>

    <h4><?php echo t('Thumbnails') ?></h4>
    <div class="row">
        <div class="col-xs-7">
            <div class="form-group ios__toggler-form-group">
                <?php echo $form->label($view->field('useCustomThumbnailsSetting'), t('Use custom thumbnails settings')) ?>
                <div class="pull-right">
                    <?php echo $togglerWidget->output($view->field('useCustomThumbnailsSetting'), 1, $useCustomThumbnailsSetting) ?>
                </div>
            </div>
        </div>
    </div>

    <table id="thumbnailSettings<?php echo $uniqID ?>" class="table table-bordered table-condensed">
        <tbody>
            <tr>
                <td style="vertical-align: middle;"><i class="fa fa-desktop fa-lg" style="padding: 0 1px;" aria-hidden="true"></i> <?php echo t('Large Desktop') ?></td>
                <td><?php echo $form->select($view->field('largeDesktopThumbnail'), $thumbnailOptions, $largeDesktopThumbnail ?? 'large') ?></td>
            </tr>
            <tr>
                <td style="vertical-align: middle;"><i class="fa fa-laptop fa-lg" style="padding: 0 1px;" aria-hidden="true"></i> <?php echo t('Desktop') ?></td>
                <td><?php echo $form->select($view->field('desktopThumbnail'), $thumbnailOptions, $desktopThumbnail ?? 'large') ?></td>
            </tr>
            <tr>
                <td style="vertical-align: middle;"><i class="fa fa-tablet fa-lg" style="padding: 0 6px;" aria-hidden="true"></i> <?php echo t('Tablet') ?></td>
                <td><?php echo $form->select($view->field('tabletThumbnail'), $thumbnailOptions, $tabletThumbnail ?? 'medium') ?></td>
            </tr>
            <tr>
                <td style="vertical-align: middle;"><i class="fa fa-mobile fa-lg" style="padding: 0 8px;" aria-hidden="true"></i> <?php echo t('Phone') ?></td>
                <td><?php echo $form->select($view->field('phoneThumbnail'), $thumbnailOptions, $phoneThumbnail ?? 'small') ?></td>
            </tr>
        </tbody>
    </table>
</fieldset>


<script>
    $(function () {
        $('#ccm-tab-content-settings<?php echo $uniqID ?>').find('input[name=useCustomThumbnailsSetting]').change(function () {
            if ($(this).is(':checked')) {
                $('#thumbnailSettings<?php echo $uniqID ?>').slideDown();
            } else {
                $('#thumbnailSettings<?php echo $uniqID ?>').slideUp();
            }
        }).trigger('change');
    })
</script>
