<?php

namespace Concrete\Package\XwLiteSlider;

use Concrete\Core\Block\BlockType\BlockType;
use Concrete\Core\Block\BlockType\Set as BlockTypeSet;
use Concrete\Core\Database\EntityManager\Provider\ProviderInterface;
use Concrete\Core\Package\Package as PackageController;
use Xanweb\LiteSlider\Module\Module;
use Concrete\Core\Support\Facade\Database;

class Controller extends PackageController implements ProviderInterface
{
    protected $pkgHandle = 'xw_lite_slider';
    protected $appVersionRequired = '8.5.2';
    protected $pkgVersion = '1.0.0';

    public function getPackageDescription()
    {
        return t('Responsive lite slider');
    }

    public function getPackageName()
    {
        return t('Lite Slider');
    }

    public function on_start()
    {
        Module::boot();
    }

    public function validate_install()
    {
        if (PHP_VERSION_ID < 70200) {
            return $this->app['error']->addError(t('This package requires PHP version %s or greater.', '7.2.0'));
        }
    }


    public function install()
    {
        $pkg = parent::install();

        $this->installComponents($pkg);

        return $pkg;
    }

    public function uninstall()
    {
        parent::uninstall();

        $this->dropTables([
            'btXwLiteSlider', 'btXwLiteSliderEntries',
        ]);
    }

    private function dropTables(array $tables)
    {
        $db = Database::connection();
        $platform = $db->getDatabasePlatform();

        foreach ($tables as $table) {
            if ($db->tableExists($table)) {
                $db->executeQuery($platform->getDropTableSQL($table));
            }
        }
    }

    /**
     * {@inheritdoc}
     */
    public function getPackageAutoloaderRegistries()
    {
        return [
            'src/Xanweb/LiteSlider' => 'Xanweb\LiteSlider',
            'vendor/xanweb/ls-common' => 'Xanweb\LsCommon',
            'vendor/xanweb/ls-js-localization' => 'Xanweb\LsJsLocalization',
            'vendor/xanweb/ls-block' => 'Xanweb\LsBlock',
            'vendor/xanweb/ls-helpers' => 'Xanweb\LsHelper',
            'vendor/xanweb/ls-html-helpers/src' => 'Xanweb\LsHtmlHelper',
            'vendor/xanweb/ls-item-list/src' => 'Xanweb\LsItemList',
            'vendor/xanweb/ls-module' => 'Xanweb\LsModule',
            'vendor/xanweb/ls-request' => 'Xanweb\LsRequest',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function getDrivers()
    {
        return [];
    }

    /**
     * Install or Update package components.
     *
     * @param \Concrete\Core\Entity\Package $pkg
     */
    private function installComponents($pkg)
    {
        $multimediaBts = BlockTypeSet::getByHandle('multimedia');
        $bt = BlockType::getByHandle('xw_lite_slider');

        if (!is_object($bt)) {
            $bt = BlockType::installBlockType('xw_lite_slider', $pkg);
        }

        if (is_object($multimediaBts)) {
            $multimediaBts->addBlockType($bt);
        }
    }
}
