<?php

namespace Xanweb\LsItemList;

use Concrete\Core\Asset\AssetList;
use Xanweb\LsJsLocalization\Config\BeforeRenderDefaultAssetJS;
use Xanweb\LsJsLocalization\ServiceProvider as JavascriptDefaultsServiceProvider;
use Xanweb\LiteSlider\Module\Module;

class ServiceProvider extends JavascriptDefaultsServiceProvider
{
    protected function _register(): void
    {
        parent::_register();

        $this->registerListeners();
        $this->registerAssets();
    }

    private function registerListeners(): void
    {
        $this->app['director']->addListener(BeforeRenderDefaultAssetJS::NAME, function (BeforeRenderDefaultAssetJS $event) {
            $event->getJavascriptAssetDefaults()->mergeWith([
                'i18n' => [
                  'confirm' => t('Are you sure?'),
                  'maxItemsExceeded' => t('Max items exceeded, you cannot add any more items.'),
                  'pageNotFound' => t('Page not found'),
                ],
                'editor' => [
                  'initRichTextEditor' => $this->getInitRichTextEditorJSFunction(),
                  'destroyRichTextEditor' => $this->getDestroyRichTextEditorJSFunction(),
                ],
            ]);
        });
    }

    private function getInitRichTextEditorJSFunction()
    {
        return $this->app['config']->get('xanweb.item_list.editor.initRichTextEditorJSFunc', function () {
            return $this->app['editor']->getEditorInitJSFunction();
        });
    }

    private function getDestroyRichTextEditorJSFunction()
    {
        return $this->app['config']->get('xanweb.item_list.editor.destroyRichTextEditorJSFunc', function () {
            return <<<EOT
function (editor) {
    var id = editor.attr('id');
    if (CKEDITOR.instances[id] !== undefined) {
        CKEDITOR.instances[id].destroy();
    }
    
    editor.remove();
    $('#cke_' + id).remove();
}
EOT;
        });
    }

    private function registerAssets(): void
    {
        $assetList = AssetList::getInstance();
        $pkg = Module::pkg();
        $assetList->registerMultiple([
            'xw/item-list' => [
                ['javascript', 'vendor/xanweb/ls-item-list/js/item-list.js', ['minify' => false], $pkg],
                ['css', 'vendor/xanweb/ls-item-list/css/item-list.css', ['minify' => false], $pkg],
            ],
            'xw/slider-form' => [
                ['javascript', 'vendor/xanweb/ls-item-list/js/slider-form.js', ['minify' => false], $pkg],
            ],
        ]);

        $assetList->registerGroupMultiple([
            'xw/item-list' => [
                [
                    ['javascript', 'jquery'],
                    ['javascript', 'underscore'],
                    ['javascript-localized', 'xw/defaults'],
                    ['javascript', 'xw/item-list'],
                    ['css', 'xw/item-list'],
                ],
            ],
            'xw/slider-form' => [
                [
                    ['javascript', 'jquery'],
                    ['javascript', 'underscore'],
                    ['javascript-localized', 'xw/defaults'],
                    ['javascript', 'xw/slider-form'],
                    ['css', 'xw/item-list'],
                ],
            ],
        ]);
    }
}
